%% e-TeX V2.0;2
% Note: the first line of this file must match the corresponding line
% in "etex.src" and "etexdefs.lib", otherwise fallback will be used.

% $Id: language.us.def 18737 2010-06-04 17:09:02Z karl $
% language.us.def (and the start of language.def)
% - initial hyphenation patterns.

% DO NOT EDIT THIS FILE (language.def)! It is generated by tlmgr.
% See language.dat (or language.us) for more information.

% It is explicitly permitted to augment this file by adding additional
% \addlanguage ... commands AFTER the first (\addlanguage {USenglish})
% which must remain as the first language added to ensure total document
% portability for pre-\language documents.  The last line of the file
% MUST be left as \uselanguage {USenglish} for the sane reason.

% Additional languages, patterns, exceptions and left- and right-hyphen
% minima may be added here, and an example is given for German.

% The five parameters for \addlanguage are:
% language, patterns file, exceptions file, left- and right-hyphen minima

%%% Next section is      E X A M P L E   O N L Y
%%% \addlanguage {German}{ghyph31}{}{2}{2}   %%% further such lines may be used;
%%% Previous section is  E X A M P L E   O N L Y

\addlanguage {USenglish}{hyphen}{}{2}{3} %%% This MUST be the first non-comment
                                         %%% line of the file

% from dehyph-exptl:
\addlanguage{german-x-2024-02-28}{dehypht-x-2024-02-28.tex}{}{2}{2}
\addlanguage{german-x-latest}{dehypht-x-2024-02-28.tex}{}{2}{2}
\addlanguage{ngerman-x-2024-02-28}{dehyphn-x-2024-02-28.tex}{}{2}{2}
\addlanguage{ngerman-x-latest}{dehyphn-x-2024-02-28.tex}{}{2}{2}
% from hyphen-afrikaans:
\addlanguage{afrikaans}{loadhyph-af.tex}{}{1}{2}
% from hyphen-albanian:
\addlanguage{albanian}{loadhyph-sq.tex}{}{2}{2}
% from hyphen-ancientgreek:
\addlanguage{ancientgreek}{loadhyph-grc.tex}{}{1}{1}
\addlanguage{ibycus}{ibyhyph.tex}{}{2}{2}
% from hyphen-arabic:
\addlanguage{arabic}{hyph-ar.tex}{}{0}{0}
% from hyphen-armenian:
\addlanguage{armenian}{loadhyph-hy.tex}{}{1}{2}
% from hyphen-basque:
\addlanguage{basque}{loadhyph-eu.tex}{}{2}{2}
% from hyphen-belarusian:
\addlanguage{belarusian}{loadhyph-be.tex}{}{2}{2}
% from hyphen-bulgarian:
\addlanguage{bulgarian}{loadhyph-bg.tex}{}{2}{2}
% from hyphen-catalan:
\addlanguage{catalan}{loadhyph-ca.tex}{}{2}{2}
% from hyphen-chinese:
\addlanguage{pinyin}{loadhyph-zh-latn-pinyin.tex}{}{1}{2}
% from hyphen-churchslavonic:
\addlanguage{churchslavonic}{loadhyph-cu.tex}{}{1}{2}
% from hyphen-coptic:
\addlanguage{coptic}{loadhyph-cop.tex}{}{1}{1}
% from hyphen-croatian:
\addlanguage{croatian}{loadhyph-hr.tex}{}{2}{2}
% from hyphen-czech:
\addlanguage{czech}{loadhyph-cs.tex}{}{2}{3}
% from hyphen-danish:
\addlanguage{danish}{loadhyph-da.tex}{}{2}{2}
% from hyphen-dutch:
\addlanguage{dutch}{loadhyph-nl.tex}{}{2}{2}
% from hyphen-english:
\addlanguage{ukenglish}{loadhyph-en-gb.tex}{}{2}{3}
\addlanguage{british}{loadhyph-en-gb.tex}{}{2}{3}
\addlanguage{UKenglish}{loadhyph-en-gb.tex}{}{2}{3}
\addlanguage{usenglishmax}{loadhyph-en-us.tex}{}{2}{3}
% from hyphen-esperanto:
\addlanguage{esperanto}{loadhyph-eo.tex}{}{2}{2}
% from hyphen-estonian:
\addlanguage{estonian}{loadhyph-et.tex}{}{2}{3}
% from hyphen-ethiopic:
\addlanguage{ethiopic}{loadhyph-mul-ethi.tex}{}{1}{1}
\addlanguage{amharic}{loadhyph-mul-ethi.tex}{}{1}{1}
\addlanguage{geez}{loadhyph-mul-ethi.tex}{}{1}{1}
% from hyphen-farsi:
\addlanguage{farsi}{hyph-fa.tex}{}{0}{0}
\addlanguage{persian}{hyph-fa.tex}{}{0}{0}
% from hyphen-finnish:
\addlanguage{finnish}{loadhyph-fi.tex}{}{2}{2}
\addlanguage{schoolfinnish}{loadhyph-fi-x-school.tex}{}{1}{1}
% from hyphen-french:
\addlanguage{french}{loadhyph-fr.tex}{}{2}{2}
\addlanguage{patois}{loadhyph-fr.tex}{}{2}{2}
\addlanguage{francais}{loadhyph-fr.tex}{}{2}{2}
% from hyphen-friulan:
\addlanguage{friulan}{loadhyph-fur.tex}{}{2}{2}
% from hyphen-galician:
\addlanguage{galician}{loadhyph-gl.tex}{}{2}{2}
% from hyphen-georgian:
\addlanguage{georgian}{loadhyph-ka.tex}{}{1}{2}
% from hyphen-german:
\addlanguage{german}{loadhyph-de-1901.tex}{}{2}{2}
\addlanguage{ngerman}{loadhyph-de-1996.tex}{}{2}{2}
\addlanguage{swissgerman}{loadhyph-de-ch-1901.tex}{}{2}{2}
% from hyphen-greek:
\addlanguage{greek}{loadhyph-el-polyton.tex}{}{1}{1}
\addlanguage{polygreek}{loadhyph-el-polyton.tex}{}{1}{1}
\addlanguage{monogreek}{loadhyph-el-monoton.tex}{}{1}{1}
% from hyphen-hebrew:
\addlanguage{hebrew}{hyph-he.tex}{}{0}{0}
% from hyphen-hungarian:
\addlanguage{hungarian}{loadhyph-hu.tex}{}{2}{2}
% from hyphen-icelandic:
\addlanguage{icelandic}{loadhyph-is.tex}{}{2}{2}
% from hyphen-indic:
\addlanguage{assamese}{loadhyph-as.tex}{}{1}{1}
\addlanguage{bengali}{loadhyph-bn.tex}{}{1}{1}
\addlanguage{gujarati}{loadhyph-gu.tex}{}{1}{1}
\addlanguage{hindi}{loadhyph-hi.tex}{}{1}{1}
\addlanguage{kannada}{loadhyph-kn.tex}{}{1}{1}
\addlanguage{malayalam}{loadhyph-ml.tex}{}{1}{1}
\addlanguage{marathi}{loadhyph-mr.tex}{}{1}{1}
\addlanguage{oriya}{loadhyph-or.tex}{}{1}{1}
\addlanguage{pali}{loadhyph-pi.tex}{}{1}{2}
\addlanguage{panjabi}{loadhyph-pa.tex}{}{1}{1}
\addlanguage{tamil}{loadhyph-ta.tex}{}{1}{1}
\addlanguage{telugu}{loadhyph-te.tex}{}{1}{1}
% from hyphen-indonesian:
\addlanguage{indonesian}{loadhyph-id.tex}{}{2}{2}
% from hyphen-interlingua:
\addlanguage{interlingua}{loadhyph-ia.tex}{}{2}{2}
% from hyphen-irish:
\addlanguage{irish}{loadhyph-ga.tex}{}{2}{3}
% from hyphen-italian:
\addlanguage{italian}{loadhyph-it.tex}{}{2}{2}
% from hyphen-kurmanji:
\addlanguage{kurmanji}{loadhyph-kmr.tex}{}{2}{2}
% from hyphen-latin:
\addlanguage{classiclatin}{loadhyph-la-x-classic.tex}{}{2}{2}
\addlanguage{latin}{loadhyph-la.tex}{}{2}{2}
\addlanguage{liturgicallatin}{loadhyph-la-x-liturgic.tex}{}{2}{2}
% from hyphen-latvian:
\addlanguage{latvian}{loadhyph-lv.tex}{}{2}{2}
% from hyphen-lithuanian:
\addlanguage{lithuanian}{loadhyph-lt.tex}{}{2}{2}
% from hyphen-macedonian:
\addlanguage{macedonian}{loadhyph-mk.tex}{}{2}{2}
% from hyphen-mongolian:
\addlanguage{mongolian}{loadhyph-mn-cyrl.tex}{}{2}{2}
\addlanguage{mongolianlmc}{loadhyph-mn-cyrl-x-lmc.tex}{}{2}{2}
% from hyphen-norwegian:
\addlanguage{bokmal}{loadhyph-nb.tex}{}{2}{2}
\addlanguage{norwegian}{loadhyph-nb.tex}{}{2}{2}
\addlanguage{norsk}{loadhyph-nb.tex}{}{2}{2}
\addlanguage{nynorsk}{loadhyph-nn.tex}{}{2}{2}
% from hyphen-occitan:
\addlanguage{occitan}{loadhyph-oc.tex}{}{2}{2}
% from hyphen-piedmontese:
\addlanguage{piedmontese}{loadhyph-pms.tex}{}{2}{2}
% from hyphen-polish:
\addlanguage{polish}{loadhyph-pl.tex}{}{2}{2}
% from hyphen-portuguese:
\addlanguage{portuguese}{loadhyph-pt.tex}{}{2}{3}
\addlanguage{portuges}{loadhyph-pt.tex}{}{2}{3}
% from hyphen-romanian:
\addlanguage{romanian}{loadhyph-ro.tex}{}{2}{2}
% from hyphen-romansh:
\addlanguage{romansh}{loadhyph-rm.tex}{}{2}{2}
% from hyphen-russian:
\addlanguage{russian}{loadhyph-ru.tex}{}{2}{2}
% from hyphen-sanskrit:
\addlanguage{sanskrit}{loadhyph-sa.tex}{}{1}{3}
% from hyphen-serbian:
\addlanguage{serbian}{loadhyph-sr-latn.tex}{}{2}{2}
\addlanguage{serbianc}{loadhyph-sr-cyrl.tex}{}{2}{2}
% from hyphen-slovak:
\addlanguage{slovak}{loadhyph-sk.tex}{}{2}{3}
% from hyphen-slovenian:
\addlanguage{slovenian}{loadhyph-sl.tex}{}{2}{2}
\addlanguage{slovene}{loadhyph-sl.tex}{}{2}{2}
% from hyphen-spanish:
\addlanguage{spanish}{loadhyph-es.tex}{}{2}{2}
\addlanguage{espanol}{loadhyph-es.tex}{}{2}{2}
% from hyphen-swedish:
\addlanguage{swedish}{loadhyph-sv.tex}{}{2}{2}
% from hyphen-thai:
\addlanguage{thai}{loadhyph-th.tex}{}{2}{3}
% from hyphen-turkish:
\addlanguage{turkish}{loadhyph-tr.tex}{}{2}{2}
% from hyphen-turkmen:
\addlanguage{turkmen}{loadhyph-tk.tex}{}{2}{2}
% from hyphen-ukrainian:
\addlanguage{ukrainian}{loadhyph-uk.tex}{}{2}{2}
% from hyphen-uppersorbian:
\addlanguage{uppersorbian}{loadhyph-hsb.tex}{}{2}{2}
% from hyphen-vietnamese:
\addlanguage{vietnamese}{hyph-vi.tex}{}{0}{0}
% from hyphen-welsh:
\addlanguage{welsh}{loadhyph-cy.tex}{}{2}{3}
%%% No changes may be made beyond this point.

\uselanguage {USenglish}             %%% This MUST be the last line of the file.
